tests package
=============

Submodules
----------

tests.conftest module
---------------------

.. automodule:: tests.conftest
    :members:
    :undoc-members:
    :show-inheritance:

tests.fixtures module
---------------------

.. automodule:: tests.fixtures
    :members:
    :undoc-members:
    :show-inheritance:

tests.test_feature_significance module
--------------------------------------

.. automodule:: tests.test_feature_significance
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: tests
    :members:
    :undoc-members:
    :show-inheritance:
